@@ -87,60 +87,56 @@ namespace stan {
       using boost::spirit::qi::raw;
 
       using boost::spirit::qi::labels::_a;
+      using boost::spirit::qi::labels::_b;
       using boost::spirit::qi::labels::_r1;
       using boost::spirit::qi::labels::_r2;
-      using boost::spirit::qi::labels::_r3;
-      using boost::spirit::qi::labels::_r4;
 
       using boost::phoenix::begin;
       using boost::phoenix::end;
 
-      // inherited features
-      //   _r1 true if sample_r allowed
-      //   _r2 source of variables allowed for assignments
-      //   _r3 true if return_r allowed
-      //   _r4 true if in loop (allowing break/continue)
-
+      //   _r1 var scope
+      //   _r2 true if in loop (allowing break/continue)
       // raw[ ] just to wrap to get line numbers
       statement_r.name("statement");
       statement_r
-        = raw[statement_sub_r(_r1, _r2, _r3, _r4)[assign_lhs_f(_val, _1)]]
+        = raw[statement_sub_r(_r1, _r2)[assign_lhs_f(_val, _1)]]
         [add_line_number_f(_val, begin(_1), end(_1))];
 
       statement_sub_r.name("statement");
       statement_sub_r
         %= no_op_statement_r                        // key ";"
-        | statement_seq_r(_r1, _r2, _r3, _r4)       // key "{"
-        | increment_log_prob_statement_r(_r1, _r2)  // key "increment_log_prob"
-        | increment_target_statement_r(_r1, _r2)    // key "target"
-        | for_statement_r(_r1, _r2, _r3)            // key "for"
-        | while_statement_r(_r1, _r2, _r3)          // key "while"
-        | break_continue_statement_r(_r4)           // key "break", "continue"
-        | statement_2_g(_r1, _r2, _r3, _r4)         // key "if"
-        | print_statement_r(_r2)                    // key "print"
-        | reject_statement_r(_r2)                   // key "reject"
-        | return_statement_r(_r2)                   // key "return"
-        | void_return_statement_r(_r2)              // key "return"
-        | assignment_r(_r2)                         // lvalue "<-"
-        | assgn_r(_r2)                              // var[idxs] <- expr
-        | sample_r(_r1, _r2)                        // expression "~"
-        | expression_g(_r2)                         // expression
+        | statement_seq_r(_r1, _r2)                 // key "{"
+        | increment_log_prob_statement_r(_r1)       // key "increment_log_prob"
+        | increment_target_statement_r(_r1)         // key "target"
+        | for_statement_r(_r1)                      // key "for"
+        | while_statement_r(_r1)                    // key "while"
+        | break_continue_statement_r(_r2)           // key "break", "continue"
+        | statement_2_g(_r1, _r2)                   // key "if"
+        | print_statement_r(_r1)                    // key "print"
+        | reject_statement_r(_r1)                   // key "reject"
+        | return_statement_r(_r1)                   // key "return"
+        | void_return_statement_r(_r1)              // key "return"
+        | assignment_r(_r1)                         // lvalue "<-"
+        | assgn_r(_r1)                              // var[idxs] <- expr
+        | sample_r(_r1)                             // expression "~"
+        | expression_g(_r1)                         // expression
         [expression_as_statement_f(_pass, _1,
                                    boost::phoenix::ref(error_msgs_))];
 
-      // _r1, _r2, _r3, _r4 same as statement_r
+      // _r1 = var scope,  _r2 = true if in loop,  _a var_decls, _b local scope
       statement_seq_r.name("sequence of statements");
       statement_seq_r
         %= lit('{')
-        > local_var_decls_r[assign_lhs_f(_a, _1)]
-        > *statement_r(_r1, _r2, _r3, _r4)
+        > eps[reset_var_scope_f(_b, _r1)]
+        > local_var_decls_r(_b)[assign_lhs_f(_a, _1)]
+        > *statement_r(_b, _r2)
         > lit('}')
         > eps[unscope_locals_f(_a, boost::phoenix::ref(var_map_))];
 
       local_var_decls_r
-        %= var_decls_g(false, local_origin);  // - constants
+        %= var_decls_g(false, _r1);  // - constants
 
-      // inherited  _r1 = true if samples allowed as statements
+      // _r1 = var scope
       increment_log_prob_statement_r.name("increment log prob statement");
       increment_log_prob_statement_r
         %= (lit("increment_log_prob") >> no_skip[!char_("a-zA-Z0-9_")])
@@ -148,57 +144,59 @@ namespace stan {
         > eps[validate_allow_sample_f(_r1, _pass,
                                       boost::phoenix::ref(error_msgs_))]
         > lit('(')
-        > expression_g(_r2)
+        > expression_g(_r1)
           [validate_non_void_expression_f(_1, _pass,
                                           boost::phoenix::ref(error_msgs_))]
         > lit(')')
         > lit(';');
 
       // just variant syntax for increment_log_prob_r (see above)
+      // _r1 = var scope
       increment_target_statement_r.name("increment target statement");
       increment_target_statement_r
         %= (lit("target") >> lit("+="))
         > eps[validate_allow_sample_f(_r1, _pass,
                                       boost::phoenix::ref(error_msgs_))]
-        > expression_g(_r2)
+        > expression_g(_r1)
           [validate_non_void_expression_f(_1, _pass,
                                           boost::phoenix::ref(error_msgs_))]
         > lit(';');
 
-      // _r1, _r2, _r3, same as statement_r
+      // _r1 = var scope
       while_statement_r.name("while statement");
       while_statement_r
         = (lit("while") >> no_skip[!char_("a-zA-Z0-9_")])
         > lit('(')
-        > expression_g(_r2)
+        > expression_g(_r1)
           [add_while_condition_f(_val, _1, _pass,
                                  boost::phoenix::ref(error_msgs_))]
         > lit(')')
-        > statement_r(_r1, _r2, _r3, true)
+        > statement_r(_r1, true)
           [add_while_body_f(_val, _1)];
 
-      // _r1 here == _r4 from statement_r
+      // _r1 = true if in loop
       break_continue_statement_r.name("break or continue statement");
       break_continue_statement_r
         %= (string("break") | string("continue"))
         > eps[validate_in_loop_f(_r1, _pass, boost::phoenix::ref(error_msgs_))]
         > lit(';');
 
-      // _r1, _r2, _r3 same as statement_r
+      // _r1 = var scope
       for_statement_r.name("for statement");
       for_statement_r
         %= (lit("for") >> no_skip[!char_("a-zA-Z0-9_")])
         > lit('(')
-        > identifier_r[add_loop_identifier_f(_1, _a, _pass,
+        > identifier_r[add_loop_identifier_f(_1, _a, _r1, _pass,
                                          boost::phoenix::ref(var_map_),
                                          boost::phoenix::ref(error_msgs_))]
         > lit("in")
-        > range_r(_r2)
+        > range_r(_r1)
         > lit(')')
-        > statement_r(_r1, _r2, _r3, true)
+        > statement_r(_r1, true)
         > eps
         [remove_loop_identifier_f(_a, boost::phoenix::ref(var_map_))];
 
+      // _r1 = var scope
       print_statement_r.name("print statement");
       print_statement_r
         %= (lit("print") >> no_skip[!char_("a-zA-Z0-9_")])
@@ -206,7 +204,7 @@ namespace stan {
         > (printable_r(_r1) % ',')
         > lit(')');
 
-      // reject
+      // _r1 = var scope
       reject_statement_r.name("reject statement");
       reject_statement_r
         %= (lit("reject") >> no_skip[!char_("a-zA-Z0-9_")])
@@ -214,6 +212,7 @@ namespace stan {
         > (printable_r(_r1) % ',')
         > lit(')');
 
+      // _r1 = var scope
       printable_r.name("printable");
       printable_r
         %= printable_string_r
@@ -231,6 +230,7 @@ namespace stan {
         %= (lexeme[char_("a-zA-Z")
                    >> *char_("a-zA-Z0-9_.")]);
 
+      // _r1 = var scope
       range_r.name("range expression pair, colon");
       range_r
         %= expression_g(_r1)
@@ -241,6 +241,7 @@ namespace stan {
            [validate_int_expr_f(_1, _pass,
                                      boost::phoenix::ref(error_msgs_))];
 
+      // _r1 = var scope
       // this one comes before assgn_r to deal with simple assignment
       assignment_r.name("variable assignment by expression");
       assignment_r
@@ -252,6 +253,7 @@ namespace stan {
                                  boost::phoenix::ref(error_msgs_))]
         > lit(';');
 
+      // _r1 = var scope
       assgn_r.name("indexed variable assginment statement");
       assgn_r
         %= var_r(_r1)
@@ -267,27 +269,32 @@ namespace stan {
            [deprecate_old_assignment_op_f(boost::phoenix::ref(error_msgs_))]
         | (lit("=") >> no_skip[!char_("=")]);
 
+      // _r1 = var scope
       var_r.name("variable for left-hand side of assignment");
       var_r
         = identifier_r
-          [identifier_to_var_f(_1, _r1, _val,  _pass,
+          [validate_lhs_var_assgn_f(_1, _r1, _val,  _pass,
                                boost::phoenix::ref(var_map_),
                                boost::phoenix::ref(error_msgs_))];
 
       // separate rule for name on expectation failure
+      // _r1 = var scope
       expression_rhs_r.name("expression assignable to left-hand side");
       expression_rhs_r
         %= expression_g(_r1);
 
+      // _r1 = var scope
       var_lhs_r.name("variable and array dimensions");
       var_lhs_r
         %= identifier_r
         >> opt_dims_r(_r1);
 
+      // _r1 = var scope
       opt_dims_r.name("array dimensions (optional)");
       opt_dims_r
         %=  *dims_r(_r1);
 
+      // _r1 = var scope
       dims_r.name("array dimensions");
       // uses silent test because errors will be reported in sliced rules
       dims_r
@@ -295,21 +302,22 @@ namespace stan {
         >> (expression_g(_r1)[validate_int_expr_silent_f(_1, _pass)] % ',')
         >> lit(']');
 
-      // inherited  _r1 = true if samples allowed as statements
+      // inherited  _r1 = var scope
       sample_r.name("distribution of expression");
       sample_r
-        %= (expression_g(_r2)
+        %= (expression_g(_r1)
             >> lit('~'))
         > eps
           [validate_allow_sample_f(_r1, _pass,
                                    boost::phoenix::ref(error_msgs_))]
-        > distribution_r(_r2)
-        > -truncation_range_r(_r2)
+        > distribution_r(_r1)
+        > -truncation_range_r(_r1)
         > lit(';')
         > eps
           [validate_sample_f(_val, boost::phoenix::ref(var_map_),
                              _pass, boost::phoenix::ref(error_msgs_))];
 
+      // _r1 = var scope
       distribution_r.name("distribution and parameters");
       distribution_r
         %= (identifier_r
@@ -317,6 +325,7 @@ namespace stan {
             >> -(expression_g(_r1) % ','))
         > lit(')');
 
+      // _r1 = var scope
       truncation_range_r.name("range pair");
       truncation_range_r
         %= lit('T')
@@ -326,7 +335,7 @@ namespace stan {
         > -expression_g(_r1)
         > lit(']');
 
-      // _r1 = allow sampling, _r2 = var origin
+      // _r1 = var scope
       return_statement_r.name("return statement");
       return_statement_r
         %= (lit("return") >> no_skip[!char_("a-zA-Z0-9_")])
@@ -334,10 +343,10 @@ namespace stan {
         >> lit(';') [validate_return_allowed_f(_r1, _pass,
                                        boost::phoenix::ref(error_msgs_))];
 
-      // _r1 = var origin
+      // _r1 = var scope
       void_return_statement_r.name("void return statement");
       void_return_statement_r
-        = lit("return")[set_void_return_f(_val)]  // = expression()]
+        = lit("return")[set_void_return_f(_val)]
         >> lit(';')[validate_void_return_allowed_f(_r1, _pass,
                                         boost::phoenix::ref(error_msgs_))];
 
