@@ -1,7 +1,7 @@
 #ifndef STAN_MCMC_FIXED_PARAM_SAMPLER_HPP
 #define STAN_MCMC_FIXED_PARAM_SAMPLER_HPP
 
-#include <stan/interface_callbacks/writer/base_writer.hpp>
+#include <stan/callbacks/writer.hpp>
 #include <stan/mcmc/base_mcmc.hpp>
 #include <stan/mcmc/sample.hpp>
 
@@ -14,8 +14,8 @@ namespace stan {
 
       sample
       transition(sample& init_sample,
-                 interface_callbacks::writer::base_writer& info_writer,
-                 interface_callbacks::writer::base_writer& error_writer) {
+                 callbacks::writer& info_writer,
+                 callbacks::writer& error_writer) {
         return init_sample;
       }
     };
