@@ -1,7 +1,7 @@
 #ifndef STAN_MCMC_STEPSIZE_COVAR_ADAPTER_HPP
 #define STAN_MCMC_STEPSIZE_COVAR_ADAPTER_HPP
 
-#include <stan/interface_callbacks/writer/base_writer.hpp>
+#include <stan/callbacks/writer.hpp>
 #include <stan/mcmc/base_adapter.hpp>
 #include <stan/mcmc/stepsize_adaptation.hpp>
 #include <stan/mcmc/covar_adaptation.hpp>
@@ -28,7 +28,7 @@ namespace stan {
                              unsigned int init_buffer,
                              unsigned int term_buffer,
                              unsigned int base_window,
-                             interface_callbacks::writer::base_writer& writer) {
+                             callbacks::writer& writer) {
         covar_adaptation_.set_window_params(num_warmup,
                                             init_buffer,
                                             term_buffer,
