@@ -1,7 +1,7 @@
 #ifndef STAN_MODEL_GRADIENT_HPP
 #define STAN_MODEL_GRADIENT_HPP
 
-#include <stan/interface_callbacks/writer/base_writer.hpp>
+#include <stan/callbacks/writer.hpp>
 #include <stan/math/rev/mat.hpp>
 #include <stan/model/model_functional.hpp>
 #include <sstream>
@@ -24,7 +24,7 @@ namespace stan {
                   const Eigen::Matrix<double, Eigen::Dynamic, 1>& x,
                   double& f,
                   Eigen::Matrix<double, Eigen::Dynamic, 1>& grad_f,
-                  stan::interface_callbacks::writer::base_writer& writer) {
+                  stan::callbacks::writer& writer) {
       std::stringstream ss;
       try {
         stan::math::gradient(model_functional<M>(model, &ss), x, f, grad_f);
