@@ -1,8 +1,8 @@
 #ifndef STAN_MATH_FWD_SCAL_FUN_ASINH_HPP
 #define STAN_MATH_FWD_SCAL_FUN_ASINH_HPP
 
-#include <math.h>
 #include <stan/math/fwd/core.hpp>
+#include <stan/math/prim/scal/fun/asinh.hpp>
 #include <stan/math/prim/scal/fun/square.hpp>
 #include <cmath>
 
@@ -11,7 +11,6 @@ namespace stan {
 
     template <typename T>
     inline fvar<T> asinh(const fvar<T>& x) {
-      using ::asinh;
       using std::sqrt;
       return fvar<T>(asinh(x.val_), x.d_ / sqrt(square(x.val_) + 1));
     }
