@@ -9,10 +9,17 @@
 namespace stan {
   namespace math {
 
+    /**
+     * Return the derivative of the log gamma function at the
+     * specified argument.
+     *
+     * @tparam T scalar type of autodiff variable
+     * @param[in] x argument
+     * @return derivative of the log gamma function at the specified
+     * argument 
+     */
     template <typename T>
-    inline
-    fvar<T>
-    digamma(const fvar<T>& x) {
+    inline fvar<T> digamma(const fvar<T>& x) {
       return fvar<T>(digamma(x.val_), x.d_ * trigamma(x.val_));
     }
   }
