@@ -9,7 +9,7 @@ namespace stan {
   namespace math {
 
     /**
-     * Return <code>true</code> if the specified matrix is square.
+     * Check if the specified matrix is square.
      *
      * This check allows 0x0 matrices.
      *
@@ -19,19 +19,17 @@ namespace stan {
      * @param name Variable name (for error messages)
      * @param y Matrix to test
      *
-     * @return <code>true</code> if the matrix is a square matrix.
      * @throw <code>std::invalid_argument</code> if the matrix
      *    is not square
      */
     template <typename T_y>
-    inline bool
+    inline void
     check_square(const char* function,
                  const char* name,
                  const Eigen::Matrix<T_y, Eigen::Dynamic, Eigen::Dynamic>& y) {
       check_size_match(function,
                        "Expecting a square matrix; rows of ", name, y.rows(),
                        "columns of ", name, y.cols());
-      return true;
     }
 
   }
