@@ -2,30 +2,31 @@
 #define STAN_MATH_PRIM_MAT_FUN_ASINH_HPP
 
 #include <stan/math/prim/mat/vectorize/apply_scalar_unary.hpp>
-#include <boost/math/special_functions/asinh.hpp>
+#include <stan/math/prim/scal/fun/asinh.hpp>
 
 namespace stan {
   namespace math {
 
     /**
      * Structure to wrap asinh() so it can be vectorized.
-     * @param x Variable.
-     * @tparam T Variable type.
-     * @return Inverse hyperbolic sine of x in radians. 
+     *
+     * @tparam T argument scalar type
+     * @param x argument
+     * @return inverse hyperbolic sine of argument in radians. 
      */
     struct asinh_fun {
       template <typename T>
       static inline T fun(const T& x) {
-        using boost::math::asinh;
         return asinh(x);
       }
     };
 
     /**
-     * Vectorized version of acos().
-     * @param x Container.
+     * Vectorized version of asinh().
+     *
      * @tparam T Container type.
-     * @return Inverse hyperbolic sine of each value in x, in radians. 
+     * @param x Container.
+     * @return Inverse hyperbolic sine of each value in the container.
      */
     template <typename T>
     inline typename apply_scalar_unary<asinh_fun, T>::return_t
