@@ -11,20 +11,18 @@ namespace stan {
     /**
      * Return a nrows x ncols submatrix starting at (i-1, j-1).
      *
-     * @param m Matrix
-     * @param i Starting row
-     * @param j Starting column
-     * @param nrows Number of rows in block
-     * @param ncols Number of columns in block
-     **/
+     * @param m Matrix.
+     * @param i Starting row.
+     * @param j Starting column.
+     * @param nrows Number of rows in block.
+     * @param ncols Number of columns in block.
+     * @throw std::out_of_range if either index is out of range.
+     */
     template <typename T>
     inline
     Eigen::Matrix<T, Eigen::Dynamic, Eigen::Dynamic>
     block(const Eigen::Matrix<T, Eigen::Dynamic, Eigen::Dynamic>& m,
           size_t i, size_t j, size_t nrows, size_t ncols) {
-      using stan::math::check_row_index;
-      using stan::math::check_column_index;
-
       check_row_index("block", "i", m, i);
       check_row_index("block", "i+nrows-1", m, i+nrows-1);
       check_column_index("block", "j", m, j);
