@@ -15,7 +15,7 @@
 #include <stan/math/prim/scal/fun/digamma.hpp>
 #include <stan/math/prim/scal/meta/length.hpp>
 #include <stan/math/prim/scal/meta/is_constant_struct.hpp>
-#include <stan/math/prim/scal/meta/VectorView.hpp>
+#include <stan/math/prim/scal/meta/scalar_seq_view.hpp>
 #include <stan/math/prim/scal/meta/VectorBuilder.hpp>
 #include <stan/math/prim/scal/meta/partials_return_type.hpp>
 #include <stan/math/prim/scal/meta/return_type.hpp>
@@ -27,6 +27,19 @@
 namespace stan {
   namespace math {
 
+    /**
+     * Returns the inverse chi square cumulative distribution function for the
+     * given variate and degrees of freedom. If given containers of matching 
+     * sizes, returns the product of probabilities.
+     *
+     * @tparam T_y type of scalar parameter
+     * @tparam T_dof type of degrees of freedom parameter
+     * @param y scalar parameter
+     * @param nu degrees of freedom parameter
+     * @return probability or product of probabilities
+     * @throw std::domain_error if y is negative or nu is nonpositive
+     * @throw std::invalid_argument if container sizes mismatch
+     */
     template <typename T_y, typename T_dof>
     typename return_type<T_y, T_dof>::type
     inv_chi_square_cdf(const T_y& y, const T_dof& nu) {
@@ -49,8 +62,8 @@ namespace stan {
                              "Random variable", y,
                              "Degrees of freedom parameter", nu);
 
-      VectorView<const T_y> y_vec(y);
-      VectorView<const T_dof> nu_vec(nu);
+      scalar_seq_view<const T_y> y_vec(y);
+      scalar_seq_view<const T_dof> nu_vec(nu);
       size_t N = max_size(y, nu);
 
       OperandsAndPartials<T_y, T_dof> operands_and_partials(y, nu);
