@@ -5,6 +5,7 @@
 #include <stan/math/prim/scal/meta/partials_return_type.hpp>
 #include <stan/math/prim/scal/meta/OperandsAndPartials.hpp>
 #include <stan/math/prim/scal/meta/include_summand.hpp>
+#include <stan/math/prim/scal/meta/scalar_seq_view.hpp>
 #include <stan/math/prim/scal/fun/constants.hpp>
 #include <stan/math/prim/scal/meta/VectorBuilder.hpp>
 #include <stan/math/prim/scal/err/check_consistent_sizes.hpp>
@@ -22,27 +23,21 @@
 namespace stan {
   namespace math {
 
-    // Negative Binomial CDF
     template <typename T_n, typename T_shape,
               typename T_inv_scale>
     typename return_type<T_shape, T_inv_scale>::type
     neg_binomial_cdf(const T_n& n, const T_shape& alpha,
                      const T_inv_scale& beta) {
-      static const char* function("stan::math::neg_binomial_cdf");
+      static const char* function("neg_binomial_cdf");
       typedef typename stan::partials_return_type<T_n, T_shape,
                                                   T_inv_scale>::type
         T_partials_return;
 
-      using stan::math::check_positive_finite;
-      using stan::math::check_consistent_sizes;
-
-      // Ensure non-zero arugment lengths
       if (!(stan::length(n) && stan::length(alpha) && stan::length(beta)))
         return 1.0;
 
       T_partials_return P(1.0);
 
-      // Validate arguments
       check_positive_finite(function, "Shape parameter", alpha);
       check_positive_finite(function, "Inverse scale parameter", beta);
       check_consistent_sizes(function,
@@ -50,19 +45,11 @@ namespace stan {
                              "Shape parameter", alpha,
                              "Inverse scale parameter", beta);
 
-      // Wrap arguments in vector views
-      VectorView<const T_n> n_vec(n);
-      VectorView<const T_shape> alpha_vec(alpha);
-      VectorView<const T_inv_scale> beta_vec(beta);
+      scalar_seq_view<const T_n> n_vec(n);
+      scalar_seq_view<const T_shape> alpha_vec(alpha);
+      scalar_seq_view<const T_inv_scale> beta_vec(beta);
       size_t size = max_size(n, alpha, beta);
 
-      // Compute vectorized CDF and gradient
-      using stan::math::value_of;
-      using stan::math::inc_beta;
-      using stan::math::inc_beta_ddz;
-      using stan::math::inc_beta_dda;
-      using stan::math::digamma;
-
       OperandsAndPartials<T_shape, T_inv_scale>
         operands_and_partials(alpha, beta);
 
@@ -73,7 +60,6 @@ namespace stan {
           return operands_and_partials.value(0.0);
       }
 
-      // Cache a few expensive function calls if alpha is a parameter
       VectorBuilder<!is_constant_struct<T_shape>::value,
                     T_partials_return, T_shape>
         digamma_alpha_vec(stan::length(alpha));
@@ -136,6 +122,6 @@ namespace stan {
       return operands_and_partials.value(P);
     }
 
-  }  // prob
-}  // stan
+  }
+}
 #endif
