@@ -33,7 +33,7 @@ namespace stan {
      * @param b Second value.
      * @return True if first variable's value is less than second value.
      */
-    inline bool operator<(const var& a, const double b) {
+    inline bool operator<(const var& a, double b) {
       return a.val() < b;
     }
 
@@ -45,7 +45,7 @@ namespace stan {
      * @param b Second variable.
      * @return True if first value is less than second variable's value.
      */
-    inline bool operator<(const double a, const var& b) {
+    inline bool operator<(double a, const var& b) {
       return a < b.val();
     }
 
