@@ -1,7 +1,7 @@
 #ifndef STAN_MATH_REV_CORE_SET_ZERO_ALL_ADJOINTS_HPP
 #define STAN_MATH_REV_CORE_SET_ZERO_ALL_ADJOINTS_HPP
 
-#include <stan/math/rev/core/chainable.hpp>
+#include <stan/math/rev/core/vari.hpp>
 #include <stan/math/rev/core/chainable_alloc.hpp>
 #include <stan/math/rev/core/chainablestack.hpp>
 
