@@ -1,13 +1,9 @@
 #ifndef STAN_MATH_REV_SCAL_FUN_CBRT_HPP
 #define STAN_MATH_REV_SCAL_FUN_CBRT_HPP
 
-#include <math.h>
+#include <stan/math/prim/scal/fun/cbrt.hpp>
 #include <stan/math/rev/core.hpp>
 
-#ifdef _MSC_VER
-#include <boost/math/special_functions/cbrt.hpp>
-using boost::math::cbrt;
-#endif
 
 namespace stan {
   namespace math {
@@ -16,7 +12,7 @@ namespace stan {
       class cbrt_vari : public op_v_vari {
       public:
         explicit cbrt_vari(vari* avi) :
-          op_v_vari(::cbrt(avi->val_), avi) {
+          op_v_vari(cbrt(avi->val_), avi) {
         }
         void chain() {
           avi_->adj_ += adj_ / (3.0 * val_ * val_);
@@ -27,8 +23,6 @@ namespace stan {
     /**
      * Returns the cube root of the specified variable (C99).
      *
-     * See ::cbrt() for the double-based version.
-     *
      * The derivative is
      *
      * \f$\frac{d}{dx} x^{1/3} = \frac{1}{3 x^{2/3}}\f$.
