@@ -1,18 +1,13 @@
 #ifndef STAN_MATH_REV_SCAL_FUN_OWENS_T_HPP
 #define STAN_MATH_REV_SCAL_FUN_OWENS_T_HPP
 
-#include <math.h>
 #include <stan/math/rev/core.hpp>
 #include <stan/math/prim/scal/fun/constants.hpp>
+#include <stan/math/prim/scal/fun/erf.hpp>
+#include <stan/math/prim/scal/fun/owens_t.hpp>
 #include <stan/math/prim/scal/fun/square.hpp>
-#include <boost/math/special_functions/owens_t.hpp>
 #include <cmath>
 
-#ifdef _MSC_VER
-#include <boost/math/special_functions/erf.hpp>
-using boost::math::erf;
-#endif
-
 namespace stan {
   namespace math {
 
@@ -20,13 +15,13 @@ namespace stan {
       class owens_t_vv_vari : public op_vv_vari {
       public:
         owens_t_vv_vari(vari* avi, vari* bvi) :
-          op_vv_vari(boost::math::owens_t(avi->val_, bvi->val_), avi, bvi) {
+          op_vv_vari(owens_t(avi->val_, bvi->val_), avi, bvi) {
         }
         void chain() {
           const double neg_avi_sq_div_2 = -square(avi_->val_) * 0.5;
           const double one_p_bvi_sq = 1.0 + square(bvi_->val_);
 
-          avi_->adj_ += adj_ * ::erf(bvi_->val_ * avi_->val_ * INV_SQRT_2)
+          avi_->adj_ += adj_ * erf(bvi_->val_ * avi_->val_ * INV_SQRT_2)
             * std::exp(neg_avi_sq_div_2) * INV_SQRT_TWO_PI * -0.5;
           bvi_->adj_ += adj_ * std::exp(neg_avi_sq_div_2 * one_p_bvi_sq)
             / (one_p_bvi_sq * 2.0 * pi());
@@ -36,10 +31,10 @@ namespace stan {
       class owens_t_vd_vari : public op_vd_vari {
       public:
         owens_t_vd_vari(vari* avi, double b) :
-          op_vd_vari(boost::math::owens_t(avi->val_, b), avi, b) {
+          op_vd_vari(owens_t(avi->val_, b), avi, b) {
         }
         void chain() {
-          avi_->adj_ += adj_ * ::erf(bd_ * avi_->val_ * INV_SQRT_2)
+          avi_->adj_ += adj_ * erf(bd_ * avi_->val_ * INV_SQRT_2)
             * std::exp(-square(avi_->val_) * 0.5)
             * INV_SQRT_TWO_PI * -0.5;
         }
@@ -48,7 +43,7 @@ namespace stan {
       class owens_t_dv_vari : public op_dv_vari {
       public:
         owens_t_dv_vari(double a, vari* bvi) :
-          op_dv_vari(boost::math::owens_t(a, bvi->val_), a, bvi) {
+          op_dv_vari(owens_t(a, bvi->val_), a, bvi) {
         }
         void chain() {
           const double one_p_bvi_sq = 1.0 + square(bvi_->val_);
