@@ -1,9 +1,9 @@
 #ifndef STAN_MATH_REV_SCAL_FUN_ROUND_HPP
 #define STAN_MATH_REV_SCAL_FUN_ROUND_HPP
 
-#include <math.h>
 #include <stan/math/rev/core.hpp>
 #include <stan/math/prim/scal/fun/is_nan.hpp>
+#include <stan/math/prim/scal/fun/round.hpp>
 #include <limits>
 
 namespace stan {
@@ -13,7 +13,7 @@ namespace stan {
       class round_vari : public op_v_vari {
       public:
         explicit round_vari(vari* avi) :
-          op_v_vari(::round(avi->val_), avi) {
+          op_v_vari(round(avi->val_), avi) {
         }
         void chain() {
           if (unlikely(is_nan(avi_->val_)))
@@ -25,8 +25,6 @@ namespace stan {
     /**
      * Returns the rounded form of the specified variable (C99).
      *
-     * See ::round() for the double-based version.
-     *
      * The derivative is zero everywhere but numbers half way between
      * whole numbers, so for convenience the derivative is defined to
      * be everywhere zero,
